API
===

Catalog
-------

.. automodule:: xscen.catalog
   :members:
   :noindex:

.. automodule:: xscen.catutils
   :members:
   :noindex:

Extraction
----------

.. automodule:: xscen.extract
   :members:
   :noindex:

Regridding
----------

.. automodule:: xscen.regrid
   :members:
   :noindex:

Bias Adjustment
---------------

.. automodule:: xscen.biasadjust
   :members: adjust train
   :noindex:

Indicators
----------

.. automodule:: xscen.indicators
   :members:
   :noindex:

Ensembles
---------

.. automodule:: xscen.ensembles
   :members:
   :noindex:

Aggregation
-----------

.. automodule:: xscen.aggregate
   :members:
   :noindex:

Diagnostics and Quality Checks
------------------------------

.. automodule:: xscen.diagnostics
   :members:
   :noindex:

Input / Output
--------------

.. automodule:: xscen.io
   :members:
   :noindex:

Spatial tools
-------------

.. automodule:: xscen.spatial
   :members:
   :noindex:

Controlled Vocabulary and Mappings
----------------------------------

.. automodule:: xscen.utils.CV
   :members:
   :noindex:

Configuration Utilities
-----------------------

.. automodule:: xscen.config
   :members:
   :noindex:

Script Utilities
----------------

.. automodule:: xscen.scripting
   :members:
   :noindex:

Packaging Utilities
-------------------

.. automodule:: xscen.utils
   :members:
   :noindex:
